# blisswebui

![blisswebui](images/blisswebui.png 'blisswebui')

Bliss Web UI provides a simple web user interface to consume the bliss [REST API](https://bliss.gitlab-pages.esrf.fr/bliss/master/blissapi.html).
